@@ -3,7 +3,7 @@
     begin                : Mon Jan 13 2003
     author               : (C) 2002 by Ricardo Niederberger Cabral
     email                : nieder|at|mail.ru
-    $Id: DuplicateWiz.py,v 1.52 2004/05/01 15:26:16 niederberger Exp $
+    $Id: DuplicateWiz.py,v 1.54 2004/10/21 02:50:16 niederberger Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,6 +31,9 @@ except:
     print "DuplicateWiz: Unable to import some imgSeek modules. Some features will not work."
 
 class DuplicateWiz(DuplicateWizard):
+    def tr(self,msg):
+        return qApp.translate('main',msg)
+    
     def __init__(self, parent,env):
         DuplicateWizard.__init__(self,parent)
         self.env = env
@@ -67,7 +70,7 @@ class DuplicateWiz(DuplicateWizard):
         self.htmlsourcelistbox.clear()
         self.bid = bid
         if not txt:
-            self.htmlsourcelistbox.insertItem("You should populate this batch with groups/volumes/directories before using it to find duplicates. Right-click on a directory or volume and select \"Add to batch\"")
+            self.htmlsourcelistbox.insertItem(self.tr("You should populate this batch with groups/volumes/directories before using it to find duplicates. Right-click on a directory or volume and select \"Add to batch\""))
             return
         for it in txt:
             self.htmlsourcelistbox.insertItem(it[1]+" - "+it[0])
@@ -82,7 +85,7 @@ class DuplicateWiz(DuplicateWizard):
         pass
 
     def DuplicateWizard_selected(self,a0):
-        if str(a0)=="Duplicates":
+        if str(a0)==str(self.tr("Duplicates")):
             self.run()
 
     def removefilebtn_clicked(self):
@@ -96,7 +99,7 @@ class DuplicateWiz(DuplicateWizard):
             it = it.itemBelow()
         if not dragids:
             return
-        res = QMessageBox.information( self, "imgSeek","Are you sure you want to physically remove the %d selected file(s) ?"%len(dragids),   QString("&Delete"), QString("Cancel"))
+        res = QMessageBox.information( self, "imgSeek",str(self.tr("Are you sure you want to physically remove the %d selected file(s) ?"))%len(dragids),   QString(self.tr("&Delete")), QString(self.tr("Cancel")))
         if res: return
         self.curdb.doNotSave = 1
         deletedOK = []                  # list of id's deleted succesfully
@@ -106,7 +109,7 @@ class DuplicateWiz(DuplicateWizard):
                 deletedOK.append(id)
             except:
                 traceback.print_exc()
-                self.parent().msgerror("Error deleting file.")
+                self.parent().msgerror(self.tr("Error deleting file."))
 
             self.curdb.removeFile(id)
         self.curdb.doNotSave = 0
@@ -115,7 +118,7 @@ class DuplicateWiz(DuplicateWizard):
         for it in dragits:
             if it.id not in deletedOK: continue
             it.setPixmap(0,QPixmap())
-            it.setText(0,"DELETED")
+            it.setText(0,self.tr("DELETED"))
 
     def avglumcompcheck_toggled(self,a0):
         self.avglthresedit.setEnabled(a0)
@@ -146,13 +149,12 @@ class DuplicateWiz(DuplicateWizard):
             pass
 
     def run(self):
-        donetext = "Search done.\nDouble-click image to show full size.\nSelect those you wish to physically remove and click on the trash button."
-        aborttext = "Search aborted.\nDouble-click image to show full size.\nSelect those you wish to physically remove and click on the trash button."
-        worktext = "Searching for duplicates, please wait...\nDouble-click image to show full size.\nSelect those you wish to physically remove and click on the trash button."
+        donetext = self.tr("Search done.\nDouble-click image to show full size.\nSelect those you wish to physically remove and click on the trash button.")
+        aborttext = self.tr("Search aborted.\nDouble-click image to show full size.\nSelect those you wish to physically remove and click on the trash button.")
+        worktext = self.tr("Searching for duplicates, please wait...\nDouble-click image to show full size.\nSelect those you wish to physically remove and click on the trash button.")
         self.resultLabel.setText(worktext)
         self.env.app.processEvents()
         self.cancelled = 0
-        #self.reslist.setCursor(QCursor(Qt.PointingHandCursor))
         doavgl = 0
         dofullsim = 0
         dodim = None
@@ -198,7 +200,7 @@ class DuplicateWiz(DuplicateWizard):
         targetlist = []
         self.curdb.crawlBatchForImg(self.bid,targetlist)
         if not len(targetlist):
-            QMessageBox.information( None, "imgSeek","You didn't select any Work Batch, or the one selected contains no image. Unable to continue. Choose a batch with images and try again.")
+            QMessageBox.information( None, "imgSeek",self.tr("You didn't select any Work Batch, or the one selected contains no image. Unable to continue. Choose a batch with images and try again."))
             return
         for id in targetlist:
             self.env.app.processEvents()
@@ -245,32 +247,32 @@ class DuplicateWiz(DuplicateWizard):
                 res = []                  # the reasons why this cid was detected as  a dup
                 if doavgl:
                     if self.curdb.imgdb.calcAvglDiff(cid,id) < lumthres:
-                        res.append("Average color match")
+                        res.append(self.tr("Average color match"))
                         found.append(cid)
                 if dofname:
                     try:
                         f1 = lower(self.curdb.meta[id]["Filename"])
                         f2 = lower(self.curdb.meta[cid]["Filename"])
                         if find(f1,f2)!= -1  or find(f2,f1) != -1:
-                            res.append("Filename match")
+                            res.append(self.tr("Filename match"))
                             found.append(cid)
                     except:
                         traceback.print_exc()
                 if dofsize:
                     if self.curdb.meta[id]["Filesize"]==self.curdb.meta[cid]["Filesize"]:
-                        res.append("Filesize match ")
+                        res.append(self.tr("Filesize match "))
                         found.append(cid)
                 if dofullsim:
                     diff = self.curdb.imgdb.calcDiff(id,cid)
                     if (-1*diff *100.0/300.0 )> simthres:
-                        res.append("Content match")
+                        res.append(self.tr("Content match"))
                         found.append(cid)
                 if dodim:
                     if (self.curdb.meta[id]["Dimensions"]==self.curdb.meta[cid]["Dimensions"])\
                     and self.curdb.meta[id]["Dimensions"]\
                     and self.curdb.meta[id]["Dimensions"]!="None":
                         if (igncommondim and self.curdb.meta[id]["Dimensions"] not in commondims) or (not igncommondim):
-                            res.append("Dimensions match: "+self.curdb.meta[id]["Dimensions"])
+                            res.append(str(self.tr("Dimensions match: "))+self.curdb.meta[id]["Dimensions"])
                             found.append(cid)
                 if res: rest.append([id,cid,res])
             if rest:                    # dups found for this id
@@ -283,8 +285,8 @@ class DuplicateWiz(DuplicateWizard):
                     rest = rest[:len(self.curdb.img.keys())-10]
                 for res in rest:
                     rstx = ""
-                    for reason in  res[2]:
-                        rstx = rstx+reason+"\n"
+                    for reason in res[2]:
+                        rstx = rstx + str(reason) + "\n"
                     if rstx:rstx = rstx[:-1]
                     lvc = QListViewItem(lvi,self.curdb.meta[res[1]]["Filename"],rstx,self.curdb.meta[res[1]]["Filesize"],os.path.split(self.curdb.img[res[1]][0])[0])
                     lvc.id = res[1]
