@@ -5,11 +5,11 @@ imgSeek modules
     begin                : Sat Dec 14 2002
     copyright            : (C) 2002 by Ricardo Niederberger Cabral
     email                : nieder|at|mail.ru
-    Time-stamp:            <2004-09-11 22:05:03 rnc>
+    Time-stamp:            <2005-04-17 18:43:21 rnc>
 
 """
 
-__version__ = "0.8.4"
+__version__ = "0.8.5"
 
 __all__ = ["Error",
            "dbCallbacks",
@@ -18,7 +18,7 @@ __all__ = ["Error",
            "IptcExtract",
            "SlideShowDialog",
            "BatchEditWnd",
-           "ImgDB",
+           "ImageDB",
            "BatchEditForm",
            "customWidgets",
            "DuplicateWiz",
