@@ -39,16 +39,26 @@ using namespace std;
 #include <math.h>
 #include <stdio.h>
 
-#ifdef ImMagick
-  /* ImageMagick includes */
+/* ImageMagick includes */
+#ifdef ImMagick  
   #include <Magick++.h>
   using namespace Magick;
 #else
-  /* QT Includes */
+/* QT Includes */
   #include <qimage.h>
 #endif
 
+/* JPEG Includes */
+#define XMD_H   // avoid primitive typedef name clashes on libjpeg
+extern "C"
+{	
+#include <jpeglib.h>
+}
+#include "jpegloader.h"
+
+
 void initImgBin() {
+  /* setup initial fixed weights that each coefficient represents */
   int i,j;
   for (i = 0;i<128;i++) for (j=0;j<128;j++) imgBin[i*128+j] = min(max(i,j),5);
 }
@@ -161,12 +171,35 @@ int addImage(const long int id, char* filename,char* thname,int doThumb,int ignD
 
 #else // use QT
   QImage image = QImage();
-  if (!image.load(filename)) {
-    return 0;
-  }
-  if ( (ignDim) && ((image.width()<= ignDim) || (image.height()<= ignDim)) ) return 2;      
-  nsig->width = image.width();
-  nsig->height = image.height();
+  
+  QString format = QImageIO::imageFormat(filename);
+  if (format=="JPEG") { // use fast jpeg loading
+    struct jpeg_decompress_struct cinfo = loadJPEG(image, filename);
+  
+    if (!cinfo.image_width) {  // error loading image
+      // try QT now.
+      if (!image.load(filename)) {
+        return 0;
+      }
+      if ( (ignDim) && ((image.width()<= ignDim) || (image.height()<= ignDim)) ) return 2;      
+      nsig->width = image.width();
+      nsig->height = image.height();     
+
+    } else {  // fast jpeg succeeded  
+      if ( (ignDim) && (((int)cinfo.image_width <= ignDim) || ((int)cinfo.image_height <= ignDim)) ) return 2;      
+      nsig->width = cinfo.image_width;
+      nsig->height = cinfo.image_height;
+    }
+    
+  } else { // use default QT image loading
+    if (!image.load(filename)) {
+      return 0;
+    }
+    if ( (ignDim) && (((int)image.width()<= ignDim) || ((int)image.height()<= ignDim)) ) return 2;      
+    nsig->width = image.width();
+    nsig->height = image.height();
+  }  
+  
   if (doThumb) {
     image.smoothScale(128,128,QImage::ScaleMin).save(thname,"PNG");
   }
@@ -396,9 +429,8 @@ long_list queryImgDataForThresFast(sigMap* tsigs, double * avgl,float thresd,int
   // will only look for average luminance
   long_list res;
   for (sigIterator sit = (*tsigs).begin(); sit!=(*tsigs).end(); sit++) { 
-    (*sit).second->score =0;
+    (*sit).second->score = 0;
     for (int c = 0;c<3;c++)  (*sit).second->score += weights[scanned][0][c]*fabs((*sit).second->avgl[c]-avgl[c]);
-    //cout << (*sit).second->score << " " << thresd << endl;
     if ((*sit).second->score < thresd) {
       res.push_back((*sit).second->id);
       (*tsigs).erase((*sit).second->id);
@@ -411,25 +443,49 @@ long_list queryImgDataForThresFast(sigMap* tsigs, double * avgl,float thresd,int
 long_list_2 clusterSim(float thresd,int fast = 0) {
   long_list_2 res;              // will hold a list of lists. ie. a list of clusters
   sigMap wSigs(sigs);           // temporary map of sigs, as soon as an image becomes part of a cluster, it's removed from this map
+  sigMap wSigsTrack(sigs);           // temporary map of sigs, as soon as an image becomes part of a cluster, it's removed from this map
 
-  for (sigIterator sit = wSigs.begin(); sit!=wSigs.end(); sit++) { // for every img on db
+  for (sigIterator sit = wSigs.begin(); sit != wSigs.end(); sit++) { // for every img on db
     long_list res2;
-    if (fast)
+    cout << "iterated" << endl;
+
+    if (fast) { 
       res2 = queryImgDataForThresFast(&wSigs,(*sit).second->avgl,thresd,1);
-    else
+    } else {
       res2 = queryImgDataForThres(&wSigs,(*sit).second->sig1,(*sit).second->sig2,(*sit).second->sig3,(*sit).second->avgl,thresd,1);
+    }
+    cout << "queried" << endl;
+    //    continue;
     long int hid = (*sit).second->id;
+    //    if () 
     wSigs.erase(hid);
-    if (res2.size()<=1) continue;
+    if (res2.size() <= 1) {
+      if (wSigs.size() <= 1)  break; // everything already added to a cluster sim. Bail out immediately, otherwise next iteration 
+                                     // will segfault when incrementing sit
+      cout << "will iterate 1" << endl;
+      continue;
+    } 
     res2.push_front(hid);
     res.push_back(res2);
+    if (wSigs.size() <= 1)  break; 
+    cout << "will iterate 2" << endl;
+    sigIterator sit2 = wSigs.end();
+    cout << "will iterate 3" << endl;
+    //    sigIterator sit3 = sit++;
+    cout << "will iterate 4" << endl;
+    cout << wSigs.size() << endl;
+    cout << res.size() << endl;
+    cout << res2.size() << endl;
+    cout << res2.size() << endl;
+    cout << "will iterate 5" << endl;
   }
   return res;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // Python Wrappers/Helpers:
-// TODO: learn how to properly wrap STL lists and such using SWIG. These helpers functs should work meanwhile...
+// TODO1: learn how to properly wrap STL lists and such using SWIG. These helpers functs should work meanwhile...
+// grr. I've already figured out how to wrap it properly, but forgot where. Maybe on imgSeekLite ? or imgseeknet ?
 //////
 
 int getLongListSize(long_list& li) {
@@ -515,6 +571,7 @@ int  queryImgFile(char* filename,int numres,int scanned) {
     Pixels view(image);
     PixelPacket *pixel_cache = view.get(0,0,128,128);
     int idx = 0;
+    //TODO: is this order inverted? check later
     for(int i = 0;i<128;i++) for(int j=0;j<128;j++) {
         rchan[idx] = pixel_cache->red;
         gchan[idx] = pixel_cache->green;
@@ -534,17 +591,23 @@ int  queryImgFile(char* filename,int numres,int scanned) {
   }
 
 #else // QT
+
   QImage image = QImage();
   if (!image.load(filename)) return 0;
   if ((image.width() != 128) || (image.height() != 128)) image = image.scale(128,128);
 
-  for(int i = 0;i<128;i++) for(int j = 0;j<128;j++) {
-      cdata1[cn] = qRed(image.pixel(j,i));
-      cdata2[cn] = qGreen(image.pixel(j,i));
-      cdata3[cn] = qBlue(image.pixel(j,i));
+  //  for(int j = 0;j<128;j++) {
+  //  for(int i = 0;i<128;i++) ( 
+ for(int i = 0;i<128;i++) for(int j = 0;j<128;j++) {  
+      cdata1[cn] = qRed(image.pixel(i,j));
+      cdata2[cn] = qGreen(image.pixel(i,j));
+      cdata3[cn] = qBlue(image.pixel(i,j));
       cn++;
+      
   }
+  
   transform(cdata1,cdata2,cdata3);
+
 #endif
 
   calcHaar(cdata1,cdata2,cdata3,sig1,sig2,sig3,avgl);
@@ -661,6 +724,24 @@ int convert(char* f1,char* f2) {
   return 0;
 }
 int magickThumb(char* f1,char* f2) {
-  return 0;
+  QImage image = QImage();
+  
+  QString format = QImageIO::imageFormat(f1);
+  if (format == "JPEG") { // use fast jpeg loading
+    struct jpeg_decompress_struct cinfo = loadJPEG(image, f1);
+  
+    if (!cinfo.image_width) {  // error loading image
+      // try QT now.
+      if (!image.load(f1)) {
+        return 0;
+      }    
+    } else { // use default QT image loading
+      if (!image.load(f1)) {
+        return 0;
+      }
+    }
+  }  
+  image.smoothScale(128,128,QImage::ScaleMin).save(f2,"PNG");  
+  return 1;
 }
-#endif
+#endif  // ImMagick
